==> 0.5.0.tar.gz: example/lib/views/text_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class TextFieldExample extends StatelessWidget {
  const TextFieldExample({ Key? key }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                content: SeniorTextField(
                  label: 'Nome',
                ),
              ),
              Panel(
                title: 'Com validator',
                content: SeniorTextField(
                  label: 'Sobrenome',
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                content: SeniorTextField(
                  label: 'Sobrenome',
                  obscureText: true,
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                content: SeniorTextField(
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                content: SeniorTextField(
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.calendar,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.7.2.tar.gz: example/lib/views/text_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class TextFieldExample extends StatelessWidget {
  const TextFieldExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                content: SeniorTextField(
                  label: 'Nome',
                  maxLength: 10,
                  maxLines: null,
                ),
              ),
              Panel(
                title: 'Com validator',
                content: SeniorTextField(
                  maxLength: 30,
                  label: 'Sobrenome',
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                content: SeniorTextField(
                  label: 'Sobrenome',
                  obscureText: true,
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                content: SeniorTextField(
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                content: SeniorTextField(
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.calendar,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
